@@ -2,7 +2,7 @@ use std::future::Future;
 use std::process;
 use std::time::{Duration, Instant};
 
-use clap::{App, Arg};
+use clap::{Arg, Command};
 use futures::future::{self, FutureExt};
 use futures::stream::StreamExt;
 
@@ -34,36 +34,28 @@ impl AsyncRuntime for SmolRuntime {
 }
 
 fn main() {
-    let matches = App::new("smol runtime example")
+    let matches = Command::new("smol runtime example")
         .version(option_env!("CARGO_PKG_VERSION").unwrap_or(""))
         .about("Demonstrates using rust-rdkafka with a custom async runtime")
         .arg(
-            Arg::with_name("brokers")
-                .short("b")
+            Arg::new("brokers")
+                .short('b')
                 .long("brokers")
                 .help("Broker list in kafka format")
-                .takes_value(true)
                 .default_value("localhost:9092"),
         )
+        .arg(Arg::new("topic").long("topic").help("topic").required(true))
         .arg(
-            Arg::with_name("topic")
-                .long("topic")
-                .help("topic")
-                .takes_value(true)
-                .required(true),
-        )
-        .arg(
-            Arg::with_name("log-conf")
+            Arg::new("log-conf")
                 .long("log-conf")
-                .help("Configure the logging format (example: 'rdkafka=trace')")
-                .takes_value(true),
+                .help("Configure the logging format (example: 'rdkafka=trace')"),
         )
         .get_matches();
 
-    setup_logger(true, matches.value_of("log-conf"));
+    setup_logger(true, matches.get_one("log-conf"));
 
-    let brokers = matches.value_of("brokers").unwrap();
-    let topic = matches.value_of("topic").unwrap().to_owned();
+    let brokers = matches.get_one::<String>("brokers").unwrap();
+    let topic = matches.get_one::<String>("topic").unwrap().to_owned();
 
     smol::block_on(async {
         let producer: FutureProducer<_, SmolRuntime> = ClientConfig::new()
